complete -c signstar-sign -s v -l verbose -d 'Increase logging verbosity'
complete -c signstar-sign -s q -l quiet -d 'Decrease logging verbosity'
complete -c signstar-sign -s h -l help -d 'Print help (see more with \'--help\')'
